Crate floe_core

Crate floe_core 

Re-exports

pub use crate::state::inspect_entity_state;
pub use crate::state::inspect_entity_state_with_base;
pub use crate::state::reset_entity_state;
pub use crate::state::reset_entity_state_with_base;
pub use checks as check;
pub use config::resolve_config_location;
pub use config::upload_to_remote_uri;
pub use config::write_bytes_to_remote_uri;
pub use config::ConfigLocation;
pub use errors::ConfigError;
pub use manifest::build_common_manifest_json;
pub use manifest::config_from_manifest_json;
pub use manifest::ManifestOptions;
pub use manifest::PathMode;
pub use profile::detect_malformed_placeholder;
pub use profile::detect_unresolved_placeholders;
pub use profile::parse_profile;
pub use profile::parse_profile_from_str;
pub use profile::validate_merged_vars;
pub use profile::validate_profile;
pub use profile::ProfileConfig;
pub use run::events::set_observer;
pub use run::events::MultiObserver;
pub use run::events::RunEvent;
pub use run::events::RunObserver;
pub use run::run;
pub use run::run_with_base;
pub use run::run_with_manifest_path;
pub use run::DryRunEntityPreview;
pub use run::EntityOutcome;
pub use run::RunOutcome;
pub use runner::parse_run_status_from_logs;
pub use runner::ConnectorRunStatus;
pub use runtime::DefaultRuntime;
pub use runtime::Runtime;
pub use vars::resolve_vars;
pub use vars::VarSources;

Modules

checks
config
errors
io
lineage
manifest
profile
report
run
runner
Run-layer helpers for connector-owned execution.
runtime
state
vars
warnings

Structs

AddEntityOptions
AddEntityOutcome
RunOptions
ValidateOptions

Functions

add_entity_to_config
extract_config_env_vars
load_config
load_config_with_profile_overrides
load_config_with_profile_vars
read_manifest_text
Read manifest JSON from any supported URI (local path, s3://, gs://, abfs://). For remote URIs the file is downloaded to a temp directory that is cleaned up before this function returns; the caller receives the raw JSON text as a String.
validate
validate_config_for_tests
validate_profile_file
validate_with_base

Type Aliases

FloeResult