Structs
- CsvRow
Error Formatter - Json
RowError Formatter - Mismatch
Outcome - RowError
- Sparse
RowErrors - Text
RowError Formatter - Unique
Tracker
Traits
Functions
- apply_
mismatch_ plan - apply_
schema_ mismatch - build_
accept_ rows - build_
errors_ formatted - build_
errors_ json - build_
row_ masks - cast_
mismatch_ counts - cast_
mismatch_ errors - Detect cast mismatches by comparing raw (string) values to typed values. If a raw value exists but the typed value is null, we treat it as a cast error.
- cast_
mismatch_ errors_ sparse - column_
index_ map - not_
null_ counts - not_
null_ errors - not_
null_ errors_ sparse - plan_
schema_ mismatch - rejected_
error_ columns - row_
error_ formatter - unique_
counts - unique_
errors - unique_
errors_ sparse