pub struct ResolvedDeltaCatalogTarget {
pub catalog_name: String,
pub type_config: CatalogTypeConfig,
pub schema: String,
pub table: String,
}Expand description
Fully resolved Unity Catalog target for a single Delta write operation.
The table storage location is taken directly from the write Target — Unity Catalog
is a post-write registration step and does not influence the write path.
Fields
catalog_name: Stringtype_config: CatalogTypeConfigschema: Stringtable: StringTrait Implementations
Sourceimpl Clone for ResolvedDeltaCatalogTarget
impl Clone for ResolvedDeltaCatalogTarget
Sourcefn clone(&self) -> ResolvedDeltaCatalogTarget
fn clone(&self) -> ResolvedDeltaCatalogTarget
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ResolvedDeltaCatalogTarget
impl RefUnwindSafe for ResolvedDeltaCatalogTarget
impl Send for ResolvedDeltaCatalogTarget
impl Sync for ResolvedDeltaCatalogTarget
impl Unpin for ResolvedDeltaCatalogTarget
impl UnsafeUnpin for ResolvedDeltaCatalogTarget
impl UnwindSafe for ResolvedDeltaCatalogTarget