pub struct LocalInputFile {
pub file: InputFile,
pub local_path: PathBuf,
pub is_ephemeral: bool,
}Expand description
An InputFile paired with a guaranteed local filesystem path.
For local sources the path is the normalized source path (no copy).
For cloud sources the path is a temp file downloaded just-in-time;
is_ephemeral is true and the file should be deleted after use.
Fields
file: InputFilelocal_path: PathBufis_ephemeral: boolTrait Implementations
Sourceimpl Clone for LocalInputFile
impl Clone for LocalInputFile
Sourcefn clone(&self) -> LocalInputFile
fn clone(&self) -> LocalInputFile
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for LocalInputFile
impl RefUnwindSafe for LocalInputFile
impl Send for LocalInputFile
impl Sync for LocalInputFile
impl Unpin for LocalInputFile
impl UnsafeUnpin for LocalInputFile
impl UnwindSafe for LocalInputFile